@@ -4,8 +4,8 @@ import time
 
 from celery.task import task
 
-from bcbio.pipeline import sample, lane, qcsummary, toplevel, storage, shared, variation
-from bcbio.variation import realign, genotype, ensemble, population, multi, recalibrate
+from bcbio.pipeline import sample, lane, qcsummary, toplevel, storage, shared, variation, validate
+from bcbio.variation import realign, genotype, ensemble, population, multi, recalibrate, vcfutils
 
 # Global configuration for tasks in the main celeryconfig module
 import celeryconfig
@@ -89,7 +89,11 @@ def variantcall_sample(*args):
 
 @task
 def combine_variant_files(*args):
-    return genotype.combine_variant_files(*args)
+    return vcfutils.combine_variant_files(*args)
+
+@task
+def concat_variant_files(*args):
+    return vcfutils.concat_variant_files(*args)
 
 @task
 def detect_sv(*args):
@@ -103,6 +107,10 @@ def combine_calls(*args):
 def prep_gemini_db(*args):
     return population.prep_gemini_db(*args)
 
+@task
+def compare_to_rm(*args):
+    return validate.compare_to_rm(*args)
+
 @task
 def test(x):
     print x
