@@ -23,7 +23,7 @@ from bcbio.distributed.transaction import file_transaction
 from bcbio.pipeline import config_utils
 from bcbio.pipeline.shared import subset_variant_regions
 from bcbio.utils import file_exists, safe_makedir
-from bcbio.variation.genotype import write_empty_vcf
+from bcbio.variation import vcfutils
 
 def run_cortex(align_bams, items, ref_file, assoc_files, region=None,
                out_file=None):
@@ -58,7 +58,7 @@ def run_cortex(align_bams, items, ref_file, assoc_files, region=None,
             _combine_variants(regional_vcfs, combine_file, ref_file, config)
             _select_final_variants(combine_file, out_file, config)
         else:
-            write_empty_vcf(out_file)
+            vcfutils.write_empty_vcf(out_file)
     return out_file
 
 def _passes_cortex_depth(line, min_depth):
@@ -138,7 +138,7 @@ def _run_cortex_on_region(region, align_bam, ref_file, work_dir, out_file_base,
         if not file_exists(out_file):
             fastq = _get_fastq_in_region(region, align_bam, out_vcf_base)
             if _count_fastq_reads(fastq, min_reads) < min_reads:
-                write_empty_vcf(out_file)
+                vcfutils.write_empty_vcf(out_file)
             else:
                 local_ref, genome_size = _get_local_ref(region, ref_file, out_vcf_base)
                 indexes = _index_local_ref(local_ref, cortex_dir, stampy_dir, kmers)
@@ -150,7 +150,7 @@ def _run_cortex_on_region(region, align_bam, ref_file, work_dir, out_file_base,
                 if cortex_out:
                     _remap_cortex_out(cortex_out, region, out_file)
                 else:
-                    write_empty_vcf(out_file)
+                    vcfutils.write_empty_vcf(out_file)
     finally:
         if os.path.exists(base_dir):
             shutil.rmtree(base_dir)
