@@ -3,11 +3,13 @@
 Handles identification of low coverage regions in defined genes of interest or the entire transcript.
 """
 import collections
+import copy
 import os
 
 import yaml
 
 from bcbio import utils
+from bcbio.distributed.transaction import file_transaction
 from bcbio.log import logger
 from bcbio.pipeline import config_utils
 from bcbio.provenance import do
@@ -25,7 +27,7 @@ def _prep_coverage_file(species, covdir, config):
         cov_kw = cov_file
         cov_file = os.path.join(covdir, "%s-%s.txt" % (species, cov_kw))
     else:
-        cov_file = os.path.abspath(cov_file)
+        cov_file = os.path.normpath(os.path.join(os.path.split(covdir)[0], cov_file))
         assert os.path.exists(cov_file), \
             "Did not find input file for coverage: %s" % cov_file
     return cov_file, cov_kw
@@ -69,11 +71,16 @@ def summary(samples, config):
     config_file, out_file = _prep_coverage_config(samples, config)
     tmp_dir = utils.safe_makedir(os.path.join(os.path.dirname(out_file), "tmp"))
     resources = config_utils.get_resources("bcbio_coverage", config)
-    jvm_opts = resources.get("jvm_opts", ["-Xms750m", "-Xmx2g"])
-    java_args = ["-Djava.io.tmpdir=%s" % tmp_dir]
-    cmd = ["java"] + jvm_opts + java_args + ["-jar", bc_jar, "multicompare", config_file,
-                                             out_file, "-c", str(config["algorithm"]["num_cores"])]
-    do.run(cmd, "Summarizing coverage with bcbio.coverage", samples[0])
+    config = copy.deepcopy(config)
+    config["algorithm"]["memory_adjust"] = {"direction": "increase",
+                                            "magnitude": config["algorithm"]["num_cores"]}
+    jvm_opts = config_utils.adjust_opts(resources.get("jvm_opts", ["-Xms750m", "-Xmx2g"]), config)
+    if not utils.file_exists(out_file):
+        with file_transaction(out_file) as tx_out_file:
+            java_args = ["-Djava.io.tmpdir=%s" % tmp_dir, "-Djava.awt.headless=true"]
+            cmd = ["java"] + jvm_opts + java_args + ["-jar", bc_jar, "multicompare", config_file,
+                                                     tx_out_file, "-c", str(config["algorithm"]["num_cores"])]
+            do.run(cmd, "Summarizing coverage with bcbio.coverage", samples[0])
     out = []
     for x in samples:
         x["coverage"] = {"summary": out_file}
