@@ -19,6 +19,7 @@ from bcbio.log import logger
 from bcbio.utils import file_exists, safe_makedir
 from bcbio.distributed.transaction import file_transaction
 from bcbio.distributed.split import grouped_parallel_split_combine
+from bcbio.pipeline import config_utils
 from bcbio.pipeline.shared import (process_bam_by_chromosome, configured_vrn_files,
                                    subset_variant_regions)
 from bcbio.variation.realign import has_aligned_reads
@@ -95,7 +96,8 @@ def haplotype_caller(align_bams, items, ref_file, assoc_files,
             with file_transaction(out_file) as tx_out_file:
                 params += ["-T", "HaplotypeCaller",
                            "-o", tx_out_file]
-                params = _gatk_location_hack(params)
+                #params = _gatk_location_hack(params)
+                broad_runner.new_resources("gatk-haplotype")
                 broad_runner.run_gatk(params)
     return out_file
 
@@ -132,43 +134,29 @@ def _gatk_location_hack(args):
 
 # ## Variant filtration -- shared functionality
 
-def _get_coverage_params(config):
-    Cov = collections.namedtuple("Cov", ["interval", "depth"])
-    return Cov(config["algorithm"].get("coverage_interval", "exome").lower(),
-               config["algorithm"].get("coverage_depth", "high").lower())
-
-def _no_vqsr(config):
-    cov = _get_coverage_params(config)
-    return cov.interval in ["regional", "exome"] or cov.depth == "low"
-
 def variant_filtration(call_file, ref_file, vrn_files, config):
     """Filter variant calls using Variant Quality Score Recalibration.
 
     Newer GATK with Haplotype calling has combined SNP/indel filtering.
     """
-    broad_runner = broad.runner_from_config(config)
     caller = config["algorithm"].get("variantcaller")
-    if caller in ["gatk-haplotype"] and not _no_vqsr(config):
-        return _variant_filtration_both(broad_runner, call_file, ref_file, vrn_files,
-                                        config)
-    elif caller in ["freebayes"]:
-        return filter_freebayes(broad_runner, call_file, ref_file, vrn_files, config)
+    if caller in ["freebayes"]:
+        return filter_freebayes(call_file, ref_file, vrn_files, config)
     # no additional filtration for callers that filter as part of call process
     elif caller in ["samtools", "varscan"]:
         return call_file
     else:
-        snp_file, indel_file = vcfutils.split_snps_indels(broad_runner, call_file, ref_file)
-        snp_filter_file = _variant_filtration_snp(broad_runner, snp_file, ref_file,
-                                                  vrn_files, config)
-        indel_filter_file = _variant_filtration_indel(broad_runner, indel_file,
-                                                      ref_file, vrn_files, config)
+        snp_file, indel_file = vcfutils.split_snps_indels(call_file, ref_file, config)
+        snp_filter_file = _variant_filtration_snp(snp_file, ref_file, vrn_files, config)
+        indel_filter_file = _variant_filtration_indel(indel_file, ref_file, vrn_files, config)
         orig_files = [snp_filter_file, indel_filter_file]
         out_file = "{base}combined.vcf".format(base=os.path.commonprefix(orig_files))
         return vcfutils.combine_variant_files(orig_files, out_file, ref_file, config)
 
-def filter_freebayes(broad_runner, in_file, ref_file, vrn_files, config):
+def filter_freebayes(in_file, ref_file, vrn_files, config):
     """Perform basic sanity filtering of FreeBayes results, removing low confidence calls.
     """
+    broad_runner = broad.runner_from_config(config)
     filters = ["QUAL < 20.0", "DP < 5"]
     return variant_filtration_with_exp(broad_runner, in_file, ref_file, "", filters)
 
@@ -191,7 +179,8 @@ def _apply_variant_recal(broad_runner, snp_file, ref_file, recal_file,
             broad_runner.run_gatk(params)
     return out_file
 
-def _shared_variant_filtration(filter_type, snp_file, ref_file, vrn_files):
+def _shared_variant_filtration(filter_type, snp_file, ref_file, vrn_files,
+                               variantcaller):
     """Share functionality for filtering variants.
     """
     recal_file = "{base}.recal".format(base=os.path.splitext(snp_file)[0])
@@ -200,12 +189,15 @@ def _shared_variant_filtration(filter_type, snp_file, ref_file, vrn_files):
               "-R", ref_file,
               "--input", snp_file,
               "--mode", filter_type,
-              "-an", "QD",
+              "-an", "DP",
               "-an", "FS",
-              "-an", "ReadPosRankSum"]
+              "-an", "ReadPosRankSum",
+              "-an", "MQRankSum"]
     if filter_type in ["SNP", "BOTH"]:
         # Haplotype Score no longer calculated for indels as of GATK 2.4
-        params.extend(["-an", "HaplotypeScore"])
+        # and only used for GATK Unified Genotyper calls
+        if variantcaller == "gatk":
+            params.extend(["-an", "HaplotypeScore"])
         params.extend(
             ["-resource:hapmap,VCF,known=false,training=true,truth=true,prior=15.0",
              vrn_files.train_hapmap,
@@ -213,14 +205,12 @@ def _shared_variant_filtration(filter_type, snp_file, ref_file, vrn_files):
              vrn_files.train_1000g_omni,
              "-resource:dbsnp,VCF,known=true,training=false,truth=false,prior=8.0",
              vrn_files.dbsnp,
-              "-an", "MQRankSum",
-              "-an", "MQ"])
+             "-an", "QD"])
     if filter_type in ["INDEL", "BOTH"]:
         assert vrn_files.train_indels, "Need indel training file specified"
         params.extend(
             ["-resource:mills,VCF,known=true,training=true,truth=true,prior=12.0",
              vrn_files.train_indels])
-    params.extend(["-an", "DP"])
     return params, recal_file, tranches_file
 
 def variant_filtration_with_exp(broad_runner, snp_file, ref_file, filter_type,
@@ -250,14 +240,14 @@ def variant_filtration_with_exp(broad_runner, snp_file, ref_file, filter_type,
 
 # ## SNP specific variant filtration
 
-def _variant_filtration_snp(broad_runner, snp_file, ref_file, vrn_files,
-                            config):
+def _variant_filtration_snp(snp_file, ref_file, vrn_files, config):
     """Filter SNP variant calls using GATK best practice recommendations.
     """
+    broad_runner = broad.runner_from_config(config)
     filter_type = "SNP"
     variantcaller = config["algorithm"].get("variantcaller", "gatk")
     params, recal_file, tranches_file = _shared_variant_filtration(
-        filter_type, snp_file, ref_file, vrn_files)
+        filter_type, snp_file, ref_file, vrn_files, variantcaller)
     assert vrn_files.train_hapmap and vrn_files.train_1000g_omni, \
            "Need HapMap and 1000 genomes training files"
     filters = ["QD < 2.0", "MQ < 40.0", "FS > 60.0",
@@ -266,7 +256,7 @@ def _variant_filtration_snp(broad_runner, snp_file, ref_file, vrn_files,
     # resulting in excessive filtering, so avoid this metric
     if variantcaller not in ["gatk-haplotype"]:
         filters.append("HaplotypeScore > 13.0")
-    if _no_vqsr(config):
+    if not config_utils.use_vqsr([config["algorithm"]]):
         return variant_filtration_with_exp(broad_runner, snp_file, ref_file, filter_type,
                                            filters)
     else:
@@ -274,33 +264,33 @@ def _variant_filtration_snp(broad_runner, snp_file, ref_file, vrn_files,
         filter_file = "{base}-filterSNP.vcf".format(base=os.path.splitext(snp_file)[0])
         if file_exists(filter_file):
             config["algorithm"]["coverage_interval"] = "regional"
-            return _variant_filtration_snp(broad_runner, snp_file, ref_file, vrn_files,
-                                           config)
+            return _variant_filtration_snp(snp_file, ref_file, vrn_files, config)
         if not file_exists(recal_file):
             with file_transaction(recal_file, tranches_file) as (tx_recal, tx_tranches):
                 params.extend(["--recal_file", tx_recal,
                                "--tranches_file", tx_tranches])
                 try:
+                    broad_runner.new_resources("gatk-vqsr")
                     broad_runner.run_gatk(params)
                 # Can fail to run if not enough values are present to train. Rerun with regional
                 # filtration approach instead
                 except:
                     config["algorithm"]["coverage_interval"] = "regional"
-                    return _variant_filtration_snp(broad_runner, snp_file, ref_file, vrn_files,
-                                                   config)
+                    return _variant_filtration_snp(snp_file, ref_file, vrn_files, config)
         return _apply_variant_recal(broad_runner, snp_file, ref_file, recal_file,
                                     tranches_file, filter_type)
 
 # ## Indel specific variant filtration
 
-def _variant_filtration_indel(broad_runner, snp_file, ref_file, vrn_files,
-                              config):
+def _variant_filtration_indel(snp_file, ref_file, vrn_files, config):
     """Filter indel variant calls using GATK best practice recommendations.
     """
+    broad_runner = broad.runner_from_config(config)
     filter_type = "INDEL"
+    variantcaller = config["algorithm"].get("variantcaller", "gatk")
     params, recal_file, tranches_file = _shared_variant_filtration(
-        filter_type, snp_file, ref_file, vrn_files)
-    if _no_vqsr(config):
+        filter_type, snp_file, ref_file, vrn_files, variantcaller)
+    if not config_utils.use_vqsr([config["algorithm"]]):
         return variant_filtration_with_exp(broad_runner, snp_file, ref_file, filter_type,
                                            ["QD < 2.0", "ReadPosRankSum < -20.0", "FS > 200.0"])
     else:
@@ -308,27 +298,11 @@ def _variant_filtration_indel(broad_runner, snp_file, ref_file, vrn_files,
             with file_transaction(recal_file, tranches_file) as (tx_recal, tx_tranches):
                 params.extend(["--recal_file", tx_recal,
                                "--tranches_file", tx_tranches])
+                broad_runner.new_resources("gatk-vqsr")
                 broad_runner.run_gatk(params)
         return _apply_variant_recal(broad_runner, snp_file, ref_file, recal_file,
                                     tranches_file, filter_type)
 
-# ## Variant filtration for combined indels and SNPs
-
-def _variant_filtration_both(broad_runner, snp_file, ref_file, vrn_files,
-                              config):
-    """Filter SNP and indel variant calls using GATK best practice recommendations.
-    """
-    filter_type = "BOTH"
-    params, recal_file, tranches_file = _shared_variant_filtration(
-        filter_type, snp_file, ref_file, vrn_files)
-    if not file_exists(recal_file):
-        with file_transaction(recal_file, tranches_file) as (tx_recal, tx_tranches):
-            params.extend(["--recal_file", tx_recal,
-                           "--tranches_file", tx_tranches])
-            broad_runner.run_gatk(params)
-    return _apply_variant_recal(broad_runner, snp_file, ref_file, recal_file,
-                                tranches_file, filter_type)
-
 # ## Variant evaluation
 
 def gatk_evaluate_variants(vcf_file, ref_file, config, dbsnp=None):
@@ -479,7 +453,7 @@ def parallel_variantcall(sample_info, parallel_fn):
     to_process = []
     finished = []
     for x in sample_info:
-        if x[0]["config"]["algorithm"]["snpcall"]:
+        if x[0]["config"]["algorithm"].get("variantcaller", "gatk"):
             to_process.extend(handle_multiple_variantcallers(x))
         else:
             finished.append(x)
@@ -493,20 +467,23 @@ def parallel_variantcall(sample_info, parallel_fn):
         finished.extend(processed)
     return finished
 
+def get_variantcallers():
+    from bcbio.variation import freebayes, cortex, samtools, varscan, mutect
+    return {"gatk": unified_genotyper,
+            "gatk-haplotype": haplotype_caller,
+            "freebayes": freebayes.run_freebayes,
+            "cortex": cortex.run_cortex,
+            "samtools": samtools.run_samtools,
+            "varscan": varscan.run_varscan,
+            "mutect": mutect.mutect_caller}
+
 def variantcall_sample(data, region=None, out_file=None):
     """Parallel entry point for doing genotyping of a region of a sample.
     """
-    from bcbio.variation import freebayes, cortex, samtools, varscan, mutect
     safe_makedir(os.path.dirname(out_file))
-    caller_fns = {"gatk": unified_genotyper,
-                  "gatk-haplotype": haplotype_caller,
-                  "freebayes": freebayes.run_freebayes,
-                  "cortex": cortex.run_cortex,
-                  "samtools": samtools.run_samtools,
-                  "varscan": varscan.run_varscan,
-                  "mutect": mutect.mutect_caller}
     sam_ref = data["sam_ref"]
     config = data["config"]
+    caller_fns = get_variantcallers()
     caller_fn = caller_fns[config["algorithm"].get("variantcaller", "gatk")]
     if isinstance(data["work_bam"], basestring):
         align_bams = [data["work_bam"]]
@@ -515,9 +492,9 @@ def variantcall_sample(data, region=None, out_file=None):
         align_bams = data["work_bam"]
         items = data["work_items"]
     call_file = "%s-raw%s" % os.path.splitext(out_file)
-    caller_fn(align_bams, items, sam_ref,
-              configured_vrn_files(config, sam_ref),
-              region, call_file)
+    call_file = caller_fn(align_bams, items, sam_ref,
+                          configured_vrn_files(config, sam_ref),
+                          region, call_file)
     if data["config"]["algorithm"].get("phasing", False) == "gatk":
         call_file = phasing.read_backed_phasing(call_file, align_bams, sam_ref, region, config)
     for ext in ["", ".idx"]:
