@@ -3,7 +3,6 @@
 http://samtools.sourceforge.net/mpileup.shtml
 """
 import os
-import subprocess
 
 from bcbio import broad
 from bcbio.utils import file_exists
@@ -11,7 +10,8 @@ from bcbio.distributed.transaction import file_transaction
 from bcbio.log import logger
 from bcbio.pipeline import config_utils
 from bcbio.pipeline.shared import subset_variant_regions
-from bcbio.variation import bamprep, realign, vcfutils
+from bcbio.provenance import do
+from bcbio.variation import annotation, bamprep, realign, vcfutils
 
 def shared_variantcall(call_fn, name, align_bams, ref_file, config,
                        assoc_files, region=None, out_file=None):
@@ -35,7 +35,9 @@ def shared_variantcall(call_fn, name, align_bams, ref_file, config,
             with file_transaction(out_file) as tx_out_file:
                 call_fn(align_bams, ref_file, config, target_regions,
                         tx_out_file)
-    return out_file
+    ann_file = annotation.annotate_nongatk_vcf(out_file, align_bams, assoc_files.dbsnp,
+                                               ref_file, config)
+    return ann_file
 
 
 def run_samtools(align_bams, items, ref_file, assoc_files, region=None,
@@ -74,4 +76,4 @@ def _call_variants_samtools(align_bams, ref_file, config, target_regions, out_fi
            "| {vcfutils} varFilter -D {max_read_depth} "
            "> {out_file}")
     logger.info(cmd.format(**locals()))
-    subprocess.check_call(cmd.format(**locals()), shell=True)
+    do.run(cmd.format(**locals()), "Variant calling with samtools", {})
